/*
 * Segment 5 Intelligente Analyseverfahren, SW-Einheit 5.2 Straßensubsegmentanalyse
 * Copyright (C) 2007-2018 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.subsegana.subsegana.domain.shared;

import java.time.*;
import java.util.*;

/**
 * Ein Datensatz vom Datenverteiler.
 *
 * @param <S> der Typ des Systemobjekts zu dem der Datensatz gehört.
 * @param <D> der Typ des Datums des Datensatzs.
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public final class Datensatz<S extends Systemobjekt, D> {

    private final LocalDateTime zeitstempel;
    private final S systemobjekt;
    private final D datum;

    public Datensatz(LocalDateTime zeitstempel, S systemobjekt, D datum) {
        this.zeitstempel = Objects.requireNonNull(zeitstempel, "zeitstempel");
        this.systemobjekt = Objects.requireNonNull(systemobjekt, "systemobjekt");
        this.datum = Objects.requireNonNull(datum, "datum");
    }

    public LocalDateTime getZeitstempel() {
        return zeitstempel;
    }

    public S getSystemobjekt() {
        return systemobjekt;
    }

    public D getDatum() {
        return datum;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Datensatz<?, ?> datensatz = (Datensatz<?, ?>) o;
        return Objects.equals(zeitstempel, datensatz.zeitstempel) &&
                Objects.equals(systemobjekt, datensatz.systemobjekt) &&
                Objects.equals(datum, datensatz.datum);
    }

    @Override
    public int hashCode() {
        return Objects.hash(zeitstempel, systemobjekt, datum);
    }

    @Override
    public String toString() {
        return "Datensatz{" +
                "zeitstempel=" + zeitstempel +
                ", systemobjekt=" + systemobjekt +
                ", datum=" + datum +
                '}';
    }

}
