/*
 * Segment 5 Intelligente Analyseverfahren, SW-Einheit 5.2 Straßensubsegmentanalyse
 * Copyright (C) 2007-2018 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.subsegana.subsegana.portals;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.iav.subsegana.subsegana.domain.shared.*;

import java.time.*;
import java.util.*;
import java.util.function.*;
import java.util.stream.*;

class Kommunikation {

    private final ClientDavInterface verbindung;

    Kommunikation(ClientDavInterface verbindung) {
        this.verbindung = verbindung;
    }

    ClientDavInterface getVerbindung() {
        return verbindung;
    }

    DataModel getModell() {
        return verbindung.getDataModel();
    }

    Collection<SystemObject> konvertiereObjekte(Collection<Systemobjekt> objekte, Predicate<Systemobjekt> istTyp) {
        Collection<String> objektPids = objekte.stream()
                .filter(istTyp::test)
                .map(Systemobjekt::getPid)
                .collect(Collectors.toList());
        return getModell().getObjectsByPid(objektPids);
    }

    DataDescription datenbeschreibung(String attributgruppePid, String aspektPid) {
        AttributeGroup atg = getModell().getAttributeGroup(attributgruppePid);
        Aspect asp = getModell().getAspect(aspektPid);
        return new DataDescription(atg, asp);
    }

    static LocalDateTime konvertiereZeitstempel(long millis) {
        return LocalDateTime.ofInstant(Instant.ofEpochMilli(millis), ZoneOffset.systemDefault());
    }

    static long konvertiereZeitstempel(LocalDateTime dateTime) {
        return dateTime.atZone(ZoneId.systemDefault()).toInstant().toEpochMilli();
    }

}
