/*
 * Segment 5 Intelligente Analyseverfahren, SW-Einheit 5.2 Straßensubsegmentanalyse
 * Copyright (C) 2007-2018 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.subsegana.subsegana.portals;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.iav.fuzzylib.fuzzylib.*;
import de.bsvrz.iav.subsegana.subsegana.domain.shared.*;
import de.bsvrz.iav.subsegana.subsegana.domain.umfelddaten.*;
import de.bsvrz.iav.subsegana.subsegana.domain.verkehrsdaten.*;
import de.bsvrz.iav.subsegana.subsegana.shared.*;
import de.bsvrz.sys.funclib.debug.*;
import de.bsvrz.sys.funclib.operatingMessage.*;

import java.text.*;
import java.util.*;

import static de.bsvrz.iav.subsegana.subsegana.domain.umfelddaten.Umfeldgroessen.*;
import static de.bsvrz.iav.subsegana.subsegana.domain.verkehrsdaten.Verkehrsgroessen.*;
import static de.bsvrz.iav.subsegana.subsegana.portals.Konstanten.*;

@SuppressWarnings("ClassFanOutComplexity")
class FuzzySetsEmpfaenger extends Kommunikation {

    private final Event<Datensatz<?, LinguistischeVariable>> fuzzySetsEmpfangen = new Event<>();

    private final Debug log = Debug.getLogger();
    private final MessageSender messageSender = MessageSender.getInstance();
    private final ClientReceiverInterface receiver = new Receiver();
    private final ObjektFactory objektFactory;

    FuzzySetsEmpfaenger(ClientDavInterface verbindung, ObjektFactory objektFactory) {
        super(verbindung);
        this.objektFactory = objektFactory;
    }

    void anmelden(Collection<Systemobjekt> objekte) {
        meldeVerkehrsdatenAn(objekte);
        meldeUmfelddatenAn(objekte);
    }

    private void meldeVerkehrsdatenAn(Collection<Systemobjekt> objekte) {
        Collection<SystemObject> messquerschnitte = konvertiereObjekte(objekte, obj -> obj instanceof Messquerschnitt);
        anmelden(messquerschnitte, ATG_ANTEIL_LKW_FUZZYSETS);
        anmelden(messquerschnitte, ATG_BEMESSUNGSDICHTE_FUZZYSETS);
        anmelden(messquerschnitte, ATG_GESCHWINDIGKEIT_FUZZYSETS);
        anmelden(messquerschnitte, ATG_VERKEHRSSTAERKE_STUNDE_FUZZYSETS);
        anmelden(messquerschnitte, ATG_VERKEHRSUNRUHE_FUZZYSETS);
        log.config(MessageFormat.format("Als Empfänger von Fuzzy-Sets für {0} Messquerschnitte angemeldet.", messquerschnitte.size()));

        Collection<SystemObject> strassenteilsegmente = konvertiereObjekte(objekte, obj -> obj instanceof Strassenteilsegment);
        anmelden(strassenteilsegmente, ATG_ANTEIL_LKW_FUZZYSETS);
        anmelden(strassenteilsegmente, ATG_BEMESSUNGSDICHTE_FUZZYSETS);
        anmelden(strassenteilsegmente, ATG_GESCHWINDIGKEIT_FUZZYSETS);
        anmelden(strassenteilsegmente, ATG_VERKEHRSSTAERKE_STUNDE_FUZZYSETS);
        anmelden(strassenteilsegmente, ATG_VERKEHRSUNRUHE_FUZZYSETS);
        log.config(MessageFormat.format("Als Empfänger von Fuzzy-Sets für {0} Strassenteilsegmenten angemeldet.", strassenteilsegmente.size()));
    }

    private void meldeUmfelddatenAn(Collection<Systemobjekt> objekte) {
        Collection<SystemObject> umfelddatenmessstellen = konvertiereObjekte(objekte, obj -> obj instanceof Umfelddatenmessstelle);
        anmelden(umfelddatenmessstellen, ATG_GLAETTE_FUZZYSETS);
        log.config(MessageFormat.format("Als Empfänger von Fuzzy-Sets für {0} Umfelddatenmessstellen angemeldet.", umfelddatenmessstellen.size()));

        Collection<SystemObject> helligkeitssensoren = konvertiereObjekte(objekte, obj -> obj instanceof Helligkeitssensor);
        anmelden(helligkeitssensoren, ATG_HELLIGKEIT_FUZZYSETS);
        log.config(MessageFormat.format("Als Empfänger von Fuzzy-Sets für {0} Helligkeitssensoren angemeldet.", helligkeitssensoren.size()));

        Collection<SystemObject> niederschlagsintensitaetssensoren = konvertiereObjekte(objekte, obj -> obj instanceof Niederschlagsintensitaetssensor);
        anmelden(niederschlagsintensitaetssensoren, ATG_NIEDERSCHLAGSINTENSITAET_FUZZYSETS);
        log.config(MessageFormat.format("Als Empfänger von Fuzzy-Sets für {0} Niederschlagsintensitätssensoren angemeldet.", niederschlagsintensitaetssensoren.size()));

        Collection<SystemObject> sichtweitesensoren = konvertiereObjekte(objekte, obj -> obj instanceof Sichtweitesensor);
        anmelden(sichtweitesensoren, ATG_SICHTWEITE_FUZZYSETS);
        log.config(MessageFormat.format("Als Empfänger von Fuzzy-Sets für {0} Sichtweitesensoren angemeldet.", sichtweitesensoren.size()));

        Collection<SystemObject> windgeschwindigkeitssensoren = konvertiereObjekte(objekte, obj -> obj instanceof Windgeschwindigkeitssensor);
        anmelden(windgeschwindigkeitssensoren, ATG_WINDGESCHWINDIGKEIT_FUZZYSETS);
        log.config(MessageFormat.format("Als Empfänger von Fuzzy-Sets für {0} Windgeschwindigkeitssensoren angemeldet.", windgeschwindigkeitssensoren.size()));

        Collection<SystemObject> windrichtungssensoren = konvertiereObjekte(objekte, obj -> obj instanceof Windrichtungssensor);
        anmelden(windrichtungssensoren, ATG_WINDRICHTUNG_FUZZYSETS);
        log.config(MessageFormat.format("Als Empfänger von Fuzzy-Sets für {0} Windrichtungssensoren angemeldet.", windrichtungssensoren.size()));
    }

    private void anmelden(Collection<SystemObject> objects, String attributgruppePid) {
        getVerbindung().subscribeReceiver(receiver, objects, datenbeschreibung(attributgruppePid, "asp.parameterSoll"), ReceiveOptions.normal(), ReceiverRole.receiver());
    }

    Datensatz<?, LinguistischeVariable> konvertiereDatensatz(ResultData result) {
        Systemobjekt objekt = konvertiereSystemobjekt(result.getObject());
        String name = bestimmeVariablenname(result.getDataDescription().getAttributeGroup().getPid());
        LinguistischeVariable fuzzySets = konvertiereFuzzySets(name, result);
        Datensatz<Systemobjekt, LinguistischeVariable> datensatz = new Datensatz<>(konvertiereZeitstempel(result.getDataTime()), objekt, fuzzySets);
        if (fuzzySets.nonNull()) {
            log.fine("Parameter für Fuzzy-Sets empfangen", datensatz);
        }
        return datensatz;
    }

    private Systemobjekt konvertiereSystemobjekt(SystemObject objekt) {
        return objektFactory.gibSystemobjekt(objekt);
    }

    @SuppressWarnings("CyclomaticComplexity")
    private String bestimmeVariablenname(String attributgruppenPid) {
        switch (attributgruppenPid) {
            case ATG_VERKEHRSSTAERKE_STUNDE_FUZZYSETS:
                return QKFZ;
            case ATG_GESCHWINDIGKEIT_FUZZYSETS:
                return VKFZ;
            case ATG_VERKEHRSUNRUHE_FUZZYSETS:
                return SKFZ;
            case ATG_ANTEIL_LKW_FUZZYSETS:
                return ALKW;
            case ATG_BEMESSUNGSDICHTE_FUZZYSETS:
                return KB;
            case ATG_GLAETTE_FUZZYSETS:
                return GLAETTE;
            case ATG_HELLIGKEIT_FUZZYSETS:
                return HELLIGKEIT;
            case ATG_NIEDERSCHLAGSINTENSITAET_FUZZYSETS:
                return NIEDERSCHLAGSINTENSITAET;
            case ATG_SICHTWEITE_FUZZYSETS:
                return SICHTWEITE;
            case ATG_WINDGESCHWINDIGKEIT_FUZZYSETS:
                return WINDGESCHWINDIGKEIT;
            case ATG_WINDRICHTUNG_FUZZYSETS:
                return WINDRICHTUNG;
            default:
                throw new IllegalStateException("[unreachable code] Nicht behandelte Attributgruppe: " + attributgruppenPid);
        }
    }

    private LinguistischeVariable konvertiereFuzzySets(String name, ResultData result) {
        try {
            if (!result.hasData()) {
                String message = MessageFormat.format(
                        "Parameter für Fuzzy-Sets {1} am Objekt {0} nicht versorgt, Fuzzyfizierung findet nicht statt.",
                        result.getObject(),
                        result.getDataDescription().getAttributeGroup()
                );
                log.warning(message);
                messageSender.sendMessage(
                        result.getObject().getPid(),
                        MessageType.SYSTEM_DOMAIN,
                        null,
                        MessageGrade.WARNING,
                        result.getObject(),
                        MessageState.MESSAGE,
                        null,
                        message
                );
                return new LinguistischeVariable(name);
            }

            Data data = result.getData();
            double min = doubleValue(data.getScaledValue("Minimum"));
            double max = doubleValue(data.getScaledValue("Maximum"));
            Wertebereich wertebereich = new Wertebereich(min, max);

            List<FuzzySet> fuzzySets = new ArrayList<>();
            Data.Array fuzzySetsArray = data.getArray(name);
            for (int i = 0; i < fuzzySetsArray.getLength(); i++) {
                Data fuzzySetItem = fuzzySetsArray.getItem(i);
                fuzzySets.addAll(konvertiereFuzzySet(fuzzySetItem, wertebereich));
            }

            return new LinguistischeVariable(name, wertebereich, fuzzySets);
        } catch (IllegalArgumentException e) {
            String message = MessageFormat.format(
                    "Parameter für Fuzzy-Sets {1} am Objekt {0} ungültig, Fuzzyfizierung findet nicht statt: {2}",
                    result.getObject(),
                    result.getDataDescription().getAttributeGroup(),
                    e.getMessage()
            );
            log.warning(message);
            messageSender.sendMessage(
                    result.getObject().getPid(),
                    MessageType.APPLICATION_DOMAIN,
                    null,
                    MessageGrade.WARNING,
                    result.getObject(),
                    MessageState.MESSAGE,
                    null,
                    message
            );
            return new LinguistischeVariable(name);
        }
    }

    private static double doubleValue(Data.NumberValue data) {
        if (data.isNumber()) {
            return data.doubleValue();
        } else {
            return data.getState().getValue();
        }
    }

    private static Collection<FuzzySet> konvertiereFuzzySet(Data fuzzySet, Wertebereich wertebereich) {
        String term = fuzzySet.getTextValue("Name").getText();
        double t1 = doubleValue(fuzzySet.getScaledValue("t1"));
        double t2 = doubleValue(fuzzySet.getScaledValue("t2"));
        double t3 = doubleValue(fuzzySet.getScaledValue("t3"));
        double t4 = doubleValue(fuzzySet.getScaledValue("t4"));
        try {
            return Collections.singleton(FuzzySet.trapez(term, t1, t2, t3, t4));
        } catch (Exception e) {
            if (t1 > t2 || t2 <= t3 || t3 > t4) {
                throw e;
            }

            return Arrays.asList(
                    FuzzySet.aufsteigendeRampe(term, t1, t2, wertebereich.getMaximum()),
                    FuzzySet.abfallendeRampe(term, wertebereich.getMinimum(), t3, t4)
            );
        }
    }

    Event<Datensatz<?, LinguistischeVariable>> fuzzySetsEmpfangen() {
        return fuzzySetsEmpfangen;
    }

    private class Receiver implements ClientReceiverInterface {

        @Override
        public void update(ResultData[] results) {
            for (ResultData r : results) {
                fuzzySetsEmpfangen.send(konvertiereDatensatz(r));
            }

        }

    }

}
